==> schoenberg_2.0.2.tar.gz: schoenberg/README.md <==
schoenberg: Tools for 12-Tone Musical Composition
======================================

[![CRAN Version](http://www.r-pkg.org/badges/version/schoenberg)](https://cran.r-project.org/package=schoenberg "CRAN version")
[![Build Status](https://travis-ci.org/jadahlke/schoenberg.svg?branch=master)](https://travis-ci.org/jadahlke/schoenberg "Build status")
[![Total Downloads](http://cranlogs.r-pkg.org/badges/grand-total/schoenberg)](http://cranlogs.r-pkg.org/badges/grand-total/schoenberg "Total downloads")

## Overview
The `schoenberg` package offers functions for creating and manipulating 12-tone (i.e., dodecaphonic) musical matrices using Arnold Schoenberg's (1923) serialism technique. This package can generate random 12-tone matrices and can generate matrices using a pre-determined sequence of notes.

## Author
`schoenberg` was written by [Jeffrey A. Dahlke](https://www.jeffreydahlke.com/).

## Installation
The official [CRAN release](https://cran.r-project.org/package=schoenberg) of `schoenberg` can be installed with the following code:
```r
install.packages("schoenberg")
```

Development versions of `schoenberg` from [GitHub](https://github.com/jadahlke/schoenberg) reflect updates made to the package between official CRAN releases. Using the [devtools](https://cran.r-project.org/package=devtools) package, the GitHub release can be installed with the following code:
```r
install.packages("devtools")
devtools::install_github("jadahlke/schoenberg")
```

## Citing `schoenberg`
To cite `schoenberg`, please refer to the package's citation information using the `citation()` function.
```r
citation("schoenberg")
```

## Reporting Issues
Please report any bugs/issues to [`schoenberg`'s GitHub issues page](https://github.com/jadahlke/schoenberg/issues).

==> schoenberg_2.0.3.tar.gz: schoenberg/README.md <==
schoenberg: Tools for 12-Tone Musical Composition
======================================

[![CRAN Version](http://www.r-pkg.org/badges/version/schoenberg)](https://cran.r-project.org/package=schoenberg "CRAN version")
[![Build Status](https://travis-ci.org/jadahlke/schoenberg.svg?branch=master)](https://app.travis-ci.com/jadahlke/schoenberg "Build status")
[![Total Downloads](https://cranlogs.r-pkg.org/badges/grand-total/schoenberg)](https://cranlogs.r-pkg.org/badges/grand-total/schoenberg "Total downloads")

## Overview
The `schoenberg` package offers functions for creating and manipulating 12-tone (i.e., dodecaphonic) musical matrices using Arnold Schoenberg's (1923) serialism technique. This package can generate random 12-tone matrices and can generate matrices using a pre-determined sequence of notes.

## Author
`schoenberg` was written by [Jeffrey A. Dahlke](https://jeffreydahlke.com/).

## Installation
The official [CRAN release](https://cran.r-project.org/package=schoenberg) of `schoenberg` can be installed with the following code:
```r
install.packages("schoenberg")
```

Development versions of `schoenberg` from [GitHub](https://github.com/jadahlke/schoenberg) reflect updates made to the package between official CRAN releases. Using the [devtools](https://cran.r-project.org/package=devtools) package, the GitHub release can be installed with the following code:
```r
install.packages("devtools")
devtools::install_github("jadahlke/schoenberg")
```

## Citing `schoenberg`
To cite `schoenberg`, please refer to the package's citation information using the `citation()` function.
```r
citation("schoenberg")
```

## Reporting Issues
Please report any bugs/issues to [`schoenberg`'s GitHub issues page](https://github.com/jadahlke/schoenberg/issues).
